<?php 
// VMware vMA Settings Manager COMPONENT
//
//include the helper file
require_once(dirname(__FILE__).'/../componenthelper.inc.php');

// respect the name
$vmwarevmasettingsmanager_component_name="vmwarevmasettingsmanager";

// run the initialization function
vmwarevmasettingsmanager_component_init();

////////////////////////////////////////////////////////////////////////
// COMPONENT INIT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function vmwarevmasettingsmanager_component_init(){
	global $vmwarevmasettingsmanager_component_name;
	
	/* Need to perform a test before creating the description */
	/* Define the test results array(); */
	$ssh_not_exists_test_results = array();

	/* Define the command */
	$ssh_not_exists_test_command = "ls /var/www/.ssh 2>&1";

	/* Execute the command */
	exec($ssh_not_exists_test_command, $ssh_not_exists_test_results);
	
	$ssh_not_exists = 0;
	foreach ($ssh_not_exists_test_results as $line) {
		if ($line == 'ls: cannot access /var/www/.ssh: No such file or directory') {
			$ssh_not_exists = 1;
			} /* End if ($line == 'ls: cannot access /var/www/.ssh: No such file or directory') { */
		} /* End foreach ($ssh_not_exists_test_results as $line) { */
		
	/* Component Description */
	$desc =
		'This component is used for defining how this Nagios XI host is configured to use the plugin box293_check_vmware (via a vMA host). It is <b>required</b> for the VMware Virtualization Wizard.<br/><br/>
		The steps listed below have <b>ALREADY</b> been completed, however they are listed in case you need to run them again.<br/>
		Establish an SSH session to this Nagios XI host as user <b>root</b><br/>
		Type <b>mkdir /var/www/.ssh</b> and press <b>Enter</b><br/>
		Type <b>cp /home/nagios/.ssh/known_hosts /var/www/.ssh/</b> and press <b>Enter</b><br/>
		Type <b>cp /home/nagios/.ssh/id_dsa /var/www/.ssh/</b> and press <b>Enter</b><br/>
		Type <b>setfacl -R -m u:apache:r-x /var/www/.ssh/</b> and press <b>Enter</b><br/>
		Type <b>exit</b> and press <b>Enter</b><br/>
		';

	if ($ssh_not_exists == 1) {
		$desc .= '
			<br/>
			<br/>
			<b>Configuration Steps REQUIRED:</b><br/>
			Establish an SSH session to this Nagios XI host as user <b>root</b><br/>
			Type <b>mkdir /var/www/.ssh</b> and press <b>Enter</b><br/>
			Type <b>cp /home/nagios/.ssh/known_hosts /var/www/.ssh/</b> and press <b>Enter</b><br/>
			Type <b>cp /home/nagios/.ssh/id_dsa /var/www/.ssh/</b> and press <b>Enter</b><br/>
			Type <b>setfacl -R -m u:apache:r-x /var/www/.ssh/</b> and press <b>Enter</b><br/>
			Type <b>exit</b> and press <b>Enter</b><br/>
			';
		} /* End if ($ssh_not_exists == 1) { */
	
	/* All components require a few arguments to be initialized correctly */
	$args = array(
		COMPONENT_NAME 				=> $vmwarevmasettingsmanager_component_name,
		COMPONENT_VERSION 			=> '2015-12-19', 
		COMPONENT_DATE 				=> '2015-12-19',
		COMPONENT_AUTHOR 			=> 'Troy Lea, Nagios Enterprises, LLC',
		COMPONENT_DESCRIPTION 		=> $desc,
		COMPONENT_TITLE 			=> 'VMware vMA Settings Manager',
		COMPONENT_CONFIGFUNCTION 	=> 'vmwarevmasettingsmanager_component_config_func',
		);
	
	/* Register this component with XI */
	register_component($vmwarevmasettingsmanager_component_name,$args);
	
	} /* End function vmwarevmasettingsmanager_component_init(){ */
	


////////////////////////////////////////////////////////////////////////
// CONFIG FUNCTIONS
////////////////////////////////////////////////////////////////////////

function vmwarevmasettingsmanager_component_config_func($mode="",$inargs,&$outargs,&$result) {
	// initialize return code and output
	$result = 0;

	$component_name = 'vmwarevmasettingsmanager';

	$output = '
		<link href="../includes/components/'.$component_name.'/'.$component_name.'.css" rel="stylesheet" type="text/css" />
		<script type="text/javascript" src="../includes/components/'.$component_name.'/'.$component_name.'.js"></script>
		';

	
	switch($mode) {
		case COMPONENT_CONFIGMODE_GETSETTINGSHTML:
			$output .= '<div class="'.$component_name.'-width700">';
		
			/* Get the settings for the component */
			$settings_raw = get_option('vmwarevmasettingsmanager_component_options');
			if($settings_raw == '') {
				/* There are currently no settings so define an array */
				$settings = array();
				//print_r('here<br/>');
				} /* End if($settings_raw == '') { */
			else {
				/* Settings are defined so unserialize them */
				$settings = unserialize($settings_raw);
				} /* End else { */
			
			$html_vma_hosts_list = '';
			$html_vma_settings = '';

			/* This is for knowing which tab to display */
			$current_tab = grab_array_var($settings,'current_tab', $component_name.'-hosts');
			if ($current_tab == $component_name.'-hosts') {
				$hosts_tab_class = $component_name.'-menuheading2';
				$hosts_tab_style = '';
				$settings_tab_class = $component_name.'-menuheading1';
				$settings_tab_style = 'style="display:none"';
				} /* End if ($current_tab == $component_name.'-hosts') { */
			else {
				$hosts_tab_class = $component_name.'-menuheading1';
				$hosts_tab_style = 'style="display:none"';
				$settings_tab_class = $component_name.'-menuheading2';
				$settings_tab_style = '';
				} /* End else { */
			
			/* These are for the vMA Hosts
			/* Get the initial values */
			$vma_hosts_list = grab_array_var($settings,'vma_hosts_list','');
			/* Get the values passed to us (usually after clicking apply) */
			$vma_hosts_list = grab_array_var($inargs,'vma_hosts_list',$vma_hosts_list);

			/* These are the Settings FOR the vMA Hosts */
			/* Get the initial values */
			$vma_host_settings_list = grab_array_var($settings,'vma_host_settings_list','');
			/* Get the values passed to us (usually after clicking apply) */
			$vma_host_settings_list = grab_array_var($inargs,'vma_host_settings_list',$vma_host_settings_list);
			$vma_host_settings_list_serial = urlencode(base64_encode(serialize($vma_host_settings_list)));

			/* Get the Default vmware object radio selection */
			$vmware_object_radio_list = grab_array_var($settings,'vmware_object_radio_list','');
			$vmware_object_radio_list_serial = urlencode(base64_encode(serialize($vmware_object_radio_list)));
		
			$vma_host_list_counter = 0;
			$vma_host_selected_flag = 0;
			
			/* Check to see if any vMA hosts have been defined */
			if (empty($vma_hosts_list)) {
				/* No custom vMA hosts */
				$html_vma_hosts_list .= 'You currently have NO vMA hosts defined, please add one as per below.';
				
				$html_vma_settings .= 'You currently have NO vMA hosts defined, please add one on the vMA Hosts tab.';
				} /* End if ($vma_hosts_list == '') { */
			else {
				/* Defined vMA Hosts */
				/* Building a table of already defined vMA Hosts */
				$html_vma_hosts_list .= '
					<div class="'.$component_name.'-width500">
						The following is a list of vMA Hosts you have previously defined.
						<div class="'.$component_name.'-spacer10"> </div>
						To <b>remove</b> vMA Host(s) from the list, <b>un-tick</b> the checkbox for that vMA Host and then click the <b>Apply Settings</b> button.
						<div class="'.$component_name.'-spacer10"> </div>
						The <b>Default</b> radio button is the vMA Host that will automatically be selected when using the VMware Virtualization wizard.
						<div class="'.$component_name.'-spacer10"> </div>
					</div>
					';
				$html_vma_hosts_list .= '<table id="vma-hosts-list-table">';
				$html_vma_hosts_list .= '<thead><tr><th class="'.$component_name.'-width20"></th><th>vMA Host Address</th><th>Name</th><th>Default</th><th>Test</th></tr></thead>';
				
				/* Building a select of already defined vMA Hosts */
				$vma_host_selected = grab_array_var($inargs,'vma_host_select','');
							
				$html_vma_settings .= 'Select a vMA Host from the list below';
				$html_vma_settings .= '<div class="'.$component_name.'-spacer10"> </div>';
				$html_vma_settings .= '<select name="vma_host_select" id="id_vma_host_select" title="vMA Host" onChange="'.$component_name.'_vma_host_select(\''.$vma_host_settings_list_serial.'\')">';
				$html_vma_settings .= 	'<option value="" selected></option>';

				/* Get the vMA host radio selection */
				$vma_hosts_list_radio = grab_array_var($settings,'vma_hosts_list_radio','');
				/* Get the value passed to us (usually after clicking apply) */
				$vma_hosts_list_radio = grab_array_var($inargs,'vma_hosts_list_radio',$vma_hosts_list_radio);
				
				/* Determining vMA host radio selection */
				$vma_hosts_list_radio_flag = 0;
				foreach ($vma_hosts_list as $nested_array) {
					if ($vma_hosts_list_radio == $nested_array[0]) {
						/* Set the flag */
						$vma_hosts_list_radio_flag = 1;
						} /* End if ($vma_hosts_list_radio == $nested_array[0]) { */
					} /* End foreach ($vma_hosts_list as $nested_array) { */

				/* Defining vMA host radio selection if no default is set */
				if ($vma_hosts_list_radio_flag == 0) {
					/* Using the first vMA host in the list */
					$vma_hosts_list_radio = $vma_hosts_list[0][0];
					} /* End if ($vma_hosts_list_radio_flag == 0) { */
				
				/* Add the hosts to the table and select */
				foreach ($vma_hosts_list as $nested_array) {
					/* Add the table row */
					$html_vma_hosts_list .= '
						<tr>
							<td><input type="checkbox" name="vma_host_checkbox_'.$vma_host_list_counter.'" id="vma_host_checkbox_'.$vma_host_list_counter.'" class="'.$component_name.'-align-center" checked></td>
							<td><input type="text" name="vma_host_address_'.$vma_host_list_counter.'" id="vma_host_address_'.$vma_host_list_counter.'" value="'.$nested_array[0].'" class="'.$component_name.'-width250"/></td>
							<td><input type="text" name="vma_host_name_'.$vma_host_list_counter.'" id="vma_host_name_'.$vma_host_list_counter.'" value="'.$nested_array[1].'" class="'.$component_name.'-width250"/></td>
							<td class="'.$component_name.'-align-center '.$component_name.'-width60"><input type="radio" name="vma_hosts_list_radio" value="'.$nested_array[0].'"'; if ($vma_hosts_list_radio == $nested_array[0]) $html_vma_hosts_list .= ' checked="checked"'; $html_vma_hosts_list .= '/></td>
							<td class="'.$component_name.'-align-center"><input type="radio" name="vma_host_test_radio" id="id_vma_host_test_radio" value="'.$nested_array[0].'"/></td>
						</tr>
						';
					
					/* Check if this item is selected */
					if ($vma_host_selected == $nested_array[0]) {
						$vma_host_list_state = ' selected';
						$vma_host_selected_flag = 1;
						} /* End if ($vma_host_selected == $nested_array[0]) { */
					else {
						/* First load might not be selected yet, we'll choose the default */
						if ($vma_hosts_list_radio == $nested_array[0]) {
							$vma_host_list_state = ' selected';
							} /* End if ($vma_hosts_list_radio == $nested_array[0]) { */
						else {
							$vma_host_list_state = '';
							} /* End else { */
						} /* End else { */

					/* Add the select option */
					$html_vma_settings .= '<option value="'.$nested_array[0].'"'.$vma_host_list_state.'>'.$nested_array[1].'</option>';
					
					$vma_host_list_counter++;
					} /* End foreach ($vma_hosts_list as $nested_array) { */
				
				$html_vma_hosts_list .= '</table>';
				
				$html_vma_settings .= '</select>';
				
				} /* End else { */

			$output .= '<div class="'.$component_name.'-spacer10"> </div>';
			
			/* Creating the HTML page */
			/* This is the menu bar */
			$output .= '
				<div id="'.$component_name.'-menubar">
					<input type="button" class="'.$hosts_tab_class.'" id="id-'.$component_name.'-hosts" onclick="'.$component_name.'_ToggleMenu(\''.$component_name.'-hosts\')" value="vMA Hosts">
					<input type="button" class="'.$settings_tab_class.'" id="id-'.$component_name.'-settings" onclick="'.$component_name.'_ToggleMenu(\''.$component_name.'-settings\')" value="VMware Settings">
				</div>
				
				<div id="'.$component_name.'-hosts" class="'.$component_name.'-togglediv" '.$hosts_tab_style.'>
					<div class="sectionTitle">vMA Explained</div>

					<table>
						<tr>
							<td class="'.$component_name.'-padding-left-right-10"><input type="button" class="'.$component_name.'-button01" onclick="'.$component_name.'_toggleMe(\'overview\')" value="Overview"></td>
							<td class="'.$component_name.'-padding-left-right-10"><input type="button" class="'.$component_name.'-button01" onclick="'.$component_name.'_toggleMe(\'what-is-vma\')" value="What is vMA?"></td>
							<td class="'.$component_name.'-padding-left-right-10"><input type="button" class="'.$component_name.'-button01" onclick="'.$component_name.'_toggleMe(\'requirements\')" value="Requirements"></td>
						</tr>
					</table>

					<div class="'.$component_name.'-spacer10"> </div>
					
					<div id="overview" class="'.$component_name.'-width500" style="display:none">
						<div class="'.$component_name.'-spacer10"> </div>
						Welcome to the VMware vMA Settings Manager component.
						<div class="'.$component_name.'-spacer10"> </div>
						This component is required for the VMware Virtualization Wizard, it is how the wizard knows what vMA server to use to talk to your VMware Virtual Infrastructure.
						<div class="'.$component_name.'-spacer10"> </div>
						The wizard monitors your VMware virtual environment by offloading the VMware checks to a vSphere Management Assistance (vMA) appliance.
						<div class="'.$component_name.'-spacer10"> </div>
						This is achieved by utilizing the plugin <b>box293_check_vmware</b>, it has been written specifically for use on the vMA. The plugin and manual can be downloaded from the <a href="http://exchange.nagios.org/directory/Plugins/Operating-Systems/*-Virtual-Environments/VMWare/box293_check_vmware/details" target="_blank"><b>Nagios Exchange</b></a>.
						<div class="'.$component_name.'-spacer20"> </div>
					</div>
					

					<div id="what-is-vma" class="'.$component_name.'-width500" style="display:none">
						<b>What is vMA?</b>
						<div class="'.$component_name.'-spacer10"> </div>
						vMA is a virtual appliance provided by VMware (free of charge) to help manage your VMware based virtual infrastructure.
						<div class="'.$component_name.'-spacer10"> </div>
						It came into existance when VMware released ESXi. ESXi is the hypervisor platform that replaced their original ESX hypervisor.
						<div class="'.$component_name.'-spacer10"> </div>
						ESXi is a locked down operating system, which is why VMware created vMA to help manage ESXi (it also manages ESX).
						<div class="'.$component_name.'-spacer10"> </div>
						An example diagram of how Nagios uses vMA is shown below:
						<div class="'.$component_name.'-spacer10"> </div>
						<img src="../includes/components/'.$component_name.'/images/vma_diagram.png">
						<div class="'.$component_name.'-spacer20"> </div>
					</div>

					
					<div id="requirements" class="'.$component_name.'-width500" style="display:none">
						<b>Requirements</b>
						<div class="'.$component_name.'-spacer10"> </div>
						You will need to have deployed the vMA appliance as per the instructions in the box293_check_vmware manual, located on the <a href="http://exchange.nagios.org/directory/Plugins/Operating-Systems/*-Virtual-Environments/VMWare/box293_check_vmware/details" target="_blank"><b>Nagios Exchange</b></a>.
						<div class="'.$component_name.'-spacer20"> </div>
					</div>


					<div class="sectionTitle">vMA Hosts Explained</div>
					This tab is for defining the vMA host(s) that you have configured Nagios XI to use.
					<div class="'.$component_name.'-spacer10"> </div>
					Once you have added a vMA host you can test to make sure:
					<div class="'.$component_name.'-spacer10"> </div>
					<ul>
						<li>Nagios XI can ping the vMA host</li>
						<li>Nagios XI can establish an SSH session with the vMA host</li>
						<li>The vMA host has the box293_check_vmware plugin located on it</li>
					</ul>
				

					<!-- The following is the already defined vMA Hosts -->
					<div class="sectionTitle">Defined vMA Hosts</div>
					'.$html_vma_hosts_list.'

					<div class="'.$component_name.'-spacer20"> </div>
				';
			if (!empty($vma_hosts_list)) {
				$output .= '
					To test a vMA Host:
					<div class="'.$component_name.'-spacer10"> </div>
					<ul>
						<li>Select the host using the <b>Test</b> radio button to the right of the host</li>
						<li>Select the test <b>Type</b> from the drop down list below</li>
						<li>Click the <b>Perform vMA Host Test</b> button</li>
						<li>The results will be displayed below</li>
					</ul>
					
					<table>
						<tr>
							<td class="'.$component_name.'-width200">Select a vMA Host Test</td>
							<td>
								<select name="vma_host_tests" id="id_vma_host_tests" title="vMA Host Tests">
									<option value="ping" selected>Ping vMA Host</option>
									<option value="ssh_config">SSH Configuration</option>
								</select>
							</td>
						</tr>
						<tr>
							<td class="'.$component_name.'-width200">Click the button to execute the test</td>
							<td ><input type="button" onclick="'.$component_name.'_test(\'vma_host\')" value="Perform vMA Host Test"></td>
						</tr>
					</table>
					';
				} /* End if (!empty($vma_hosts_list)) { */

			$output .= '					
					<div id="'.$component_name.'-vma-host-test-throbber" style="display:none">
						<div class="'.$component_name.'-spacer10"> </div>
						'.get_throbber_html().'
					</div>

					<div id="'.$component_name.'-vma-host-test-results" style="display:none">
						<!-- This will be populated when a vma host test is performed -->
					</div>
					
					<!-- The following is to allow the user to add a vMA Host -->
					<div class="sectionTitle">Add a vMA Host</div>
					To <b>add</b> a vMA Host:
					<div class="'.$component_name.'-spacer5"> </div>
					<ul>
						<li><b>Tick</b> the checkbox</li>
						<li>
							Type the <b>IP Address</b> or <b>DNS Name</b> of the vMA Host
							<ul><li><i><b>Note:</b> DNS names are CaSe SeNsAtIvE</i></li></ul>
						</li>
						<li>Type the <b>Name</b> it will be known as</li>
						<li>Click the <b>Apply Settings</b> button</li>
					</ul>
					 
					<table>
						<tr><td class="'.$component_name.'-align-right"><b>Address Example:</b></td><td class="'.$component_name.'-width10"></td><td><i>192.168.1.233 or vMA.domain.Local</i></td></tr>
						<tr><td class="'.$component_name.'-align-right"><b>Name Example:</b></td><td class="'.$component_name.'-width10"></td><td><i>192.168.1.233 or vMA Production</i></td></tr>
					</table>
					
					<div class="'.$component_name.'-spacer20"> </div>

					<table>
					<thead><tr><th class="'.$component_name.'-width20"></th><th>vMA Host Address</th><th>Name</th></tr></thead>
						<tr>
							<td><input type="checkbox" name="vma_host_checkbox_'.$vma_host_list_counter.'" id="vma_host_checkbox_'.$vma_host_list_counter.'" class="'.$component_name.'-align-center"></td>
							<td><input type="text" name="vma_host_address_'.$vma_host_list_counter.'" id="vma_host_address_'.$vma_host_list_counter.'" class="'.$component_name.'-width250"/></td>
							<td><input type="text" name="vma_host_name_'.$vma_host_list_counter.'" id="vma_host_name_'.$vma_host_list_counter.'" class="'.$component_name.'-width250"/></td>
						</tr>
					</table>

					<div class="'.$component_name.'-spacer20"> </div>
				</div>	
				
				
				<div id="'.$component_name.'-settings" class="'.$component_name.'-togglediv '.$component_name.'-width500" '.$settings_tab_style.'>
					<div class="sectionTitle">VMware Settings Explained</div>
					This tab is for defining the VMware servers that the vMA host will perform the checks against.
					<div class="'.$component_name.'-spacer10"> </div>
					A VMware server can be a vCenter Server OR an ESX(i) host.
					<div class="'.$component_name.'-spacer10"> </div>
					You will need to have configured the VMware credentials on the vMA appliance as per the instructions in the box293_check_vmware manual, located on the <a href="http://exchange.nagios.org/directory/Plugins/Operating-Systems/*-Virtual-Environments/VMWare/box293_check_vmware/details" target="_blank"><b>Nagios Exchange</b></a>.
					<div class="'.$component_name.'-spacer10"> </div>
					Once you have added a Vmware Server you can test to make sure:
					<div class="'.$component_name.'-spacer10"> </div>
					<ul>	
						<li>The vMA host can ping the VMware Server</li>
						<li>
							The credentials on the vMA host work against the selected VMware Server
							<ul>
								<li>The credentials are stored in the Credentials Repository on the vMA host</li>
							</ul>
						</li>
					</ul>

					<div class="sectionTitle">Defined vMA Hosts</div>
					'.$html_vma_settings.'
					
					<div class="'.$component_name.'-spacer10"> </div>
					
					<div id="'.$component_name.'-settings-display-host" style="display:none">
						<!-- This will be populated when a host is selected from the list -->
					</div>
				
				</div>
				<div class="'.$component_name.'-spacer20"> </div>
				
				<input type="hidden" name="vma_host_list_counter" id="vma_host_list_counter" value="'.$vma_host_list_counter.'">
				<input type="hidden" name="vmware_object_radio_list" id="vmware_object_radio_list" value="'.$vmware_object_radio_list_serial.'">
				';
			if (!empty($vma_hosts_list)) {
				$output .= '
					<script>'.$component_name.'_vma_host_select(\''.$vma_host_settings_list_serial.'\')</script>
					';
				} /* End if (!empty($vma_hosts_list)) {

			/* If a vMA host was previously selected, load the options list */
			if ($vma_host_selected_flag == 1) {
				$output .= '<script>'.$component_name.'_vma_host_select(\''.$vma_host_settings_list_serial.'\')</script>';
				} /* End if ($vma_host_selected_flag == 1) { */

			$output .= '
				<input type="hidden" name="vma_current_tab" id="id_vma_current_tab" value="'.$current_tab.'">
				</div>
				';
			break; /* End case COMPONENT_CONFIGMODE_GETSETTINGSHTML: */

			
		case COMPONENT_CONFIGMODE_SAVESETTINGS:
		//	$inargs_keys = array_keys($inargs);
		//	print_r('inargs_keys: ' . $inargs_keys . '<br/>');
		//	foreach ($inargs_keys as $argtest) {
		//		print_r('argument: ' . $argtest . '<br/>');
		//		}

			/* Get the settings for the component */
			$settings_old_raw = get_option('vmwarevmasettingsmanager_component_options');
			if($settings_old_raw == '') {
				/* There are currently no settings so define an array */
				$settings_old = array();
				} /* End if($settings_raw == '') { */
			else {
				/* Settings are defined so unserialize them */
				$settings_old = unserialize($settings_old_raw);
				} /* End else { */

			/* Get the vMA Host list counter */
			$vma_host_list_counter = grab_array_var($inargs,'vma_host_list_counter','');
			//print_r('$vma_host_list_counter: ' . $vma_host_list_counter . '<br />');
			
			/* Define the array to be used for the vMA Hosts list */
			$vma_hosts_list = array();
			
			/* Get the vMA Host Settings list array*/
			$vma_host_settings_list = grab_array_var($settings_old,'vma_host_settings_list','');
					
			/* Get the Default vMA host radio selection */
			$vma_hosts_list_radio = grab_array_var($inargs,'vma_hosts_list_radio','');

			/* Get the Default vmware object radio list */
			$vmware_object_radio_list = grab_array_var($settings_old,'vmware_object_radio_list','');

			$current_tab = grab_array_var($inargs,'vma_current_tab', '');
			
			// Validation variables
			$errors = 0;
			$errmsg = array();
			$vma_hosts_list_radio_flag = 0;
			$vmware_object_default_radio_flag = 0;

			/* Loop through the defined vMA Hosts and add them to an array */
			for ($c = 0; $c <= $vma_host_list_counter; $c++) {
				$checkbox_host = 'vma_host_checkbox_' . $c;
				$checkbox_host_value = grab_array_var($inargs,$checkbox_host,'');
				//print_r('checkbox_host ' . $c . ': ' . $checkbox_host_value . '<br />');
					
				if ($checkbox_host_value == 'on') {
					/* Get the values of the fields */
					$address = 'vma_host_address_' . $c;
					$address_value = grab_array_var($inargs,$address,'');
					$name = 'vma_host_name_' . $c;
					$name_value = grab_array_var($inargs,$name,'');
					
					$human_number = $c + 1;
					/* Check to make sure the vMA Host Address field is not blank */
					if ($address_value == '') {
						$errmsg[$errors++] = 'vMA Host Address CANNOT be left blank <i>(checkbox number '.$human_number.')</i>';
						} /* End if ($address_value == '') { */
					elseif ($name_value == '') {
						/* Check to make sure the vMA Host Name field is not blank */
						$errmsg[$errors++] = 'vMA Host Name CANNOT be left blank <i>(checkbox number '.$human_number.')</i>';
						} /* End elseif ($name_value == '') { */
					else {
						/* Store this vMA Host in the vma_hosts_list array */
						//print_r('address_value: ' . $address_value . '<br/>');
						//print_r('name_value: ' . $name_value . '<br/>');
						$vma_hosts_list[$c][0] = $address_value;
						$vma_hosts_list[$c][1] = $name_value;

						/* Need to check for a radio default */
						if ($vma_hosts_list_radio == $address_value) {
							$vma_hosts_list_radio_flag++;
							} /* End if ($vma_hosts_list_radio == $address_value) { */
						} /* End else { */
					} /* End if ($checkbox_host_value == 'on') { */
				} /* End for ($c = 0; $c <= $vma_host_list_counter; $c++) { */

			/* Need to do double check for a radio default */
			if ($vma_hosts_list_radio_flag == 0) {
				if (count($vma_hosts_list) >= 1) {
					/* Just use the first item in the list */
					$vma_hosts_list_radio = $vma_hosts_list[0][0];
					} /* End if (count($vma_hosts_list) >= 1) { */
				} /* End if ($vma_hosts_list_radio_flag == 0) { */
			
			/* Work out if a vMA host was selected to Add settings*/
			$vma_host_selected_value = grab_array_var($inargs,'vma_host_select','');
			$vma_host_selected_value_modified = preg_replace('/\./', '_', $vma_host_selected_value);
			//print_r('vma_host_selected_value_modified: ' . $vma_host_selected_value_modified . '<br/>');

			/* Get the vMA Host options counter */
			$vma_host_options_counter = grab_array_var($inargs,'vma_host_options_counter','');
			//print_r('vma_host_options_counter: ' . $vma_host_options_counter . '<br/>');
			
			/* Determine if we need to add vMA Host Settings */
			if ($vma_host_selected_value != '') {
				/* Get the Default vmware object radio selection */
				$vmware_object_default_radio = grab_array_var($inargs,'vmware_object_default_radio_' . $vma_host_selected_value_modified,'');
				//print_r('vmware_object_default_radio "' . $vmware_object_default_radio . '"<br/>');

				/* Loop through the defined vMA Host Options add them to an array */
				for ($c = 0; $c <= $vma_host_options_counter; $c++) {
					//print_r('$c: ' . $c . '<br/>');
					/* Get the checkbox value */
					$checkbox_vmware_object_setting = 'vmware_object_checkbox_' . $vma_host_selected_value_modified . '_' . $c;
					$checkbox_vmware_object_setting_value = grab_array_var($inargs,$checkbox_vmware_object_setting,'');
					//print_r('checkbox_vmware_object_setting "' . $checkbox_vmware_object_setting . '"<br/>');
					//print_r('checkbox_vmware_object_setting_value "' . $checkbox_vmware_object_setting_value . '"<br/>');

					/* Find out if the checkbox was selected */
					if ($checkbox_vmware_object_setting_value == 'on') {
						/* Get the values of the fields */
						$vmware_object_address = 'vmware_object_address_' . $vma_host_selected_value_modified . '_' . $c;
						$vmware_object_address_value = grab_array_var($inargs,$vmware_object_address,'');
						$vmware_object_type = 'vmware_object_type_' . $vma_host_selected_value_modified . '_' . $c;
						$vmware_object_type_value = grab_array_var($inargs,$vmware_object_type,'');

						/* Check to make sure the VMware Object Address field is not blank */
						if ($vmware_object_address_value == '') {
							$errmsg[$errors++] = 'vCenter Server OR ESX(i) Host Address CANNOT be left blank <i>(Adding vMA Host Settings)</i>';
							} /* End if ($vmware_object_address_value == '') { */
						else {
							/* Store this vMA Host in the vma_host_settings_list array */
							$vma_host_settings_list[$vma_host_selected_value][$c][0] = $vmware_object_address_value;
							$vma_host_settings_list[$vma_host_selected_value][$c][1] = $vmware_object_type_value;
							
							/* Need to check for a radio default */
							if ($vmware_object_default_radio == $vmware_object_address_value) {
								$vmware_object_radio_list[$vma_host_selected_value] = $vmware_object_default_radio;
								$vmware_object_default_radio_flag++;
								} /* End if ($vmware_object_default_radio == $vmware_object_address_value) { */
							} /* End else { */
						} /* End if ($checkbox_vmware_object_setting_value == 'on') { */
					else {
						if (!isset($vma_host_settings_list[$vma_host_selected_value])) {
							//print_r('!isset($vma_host_settings_list[$vma_host_selected_value]) <br/>');
							} /* End if (!isset($vma_host_settings_list[$vma_host_selected_value])) { */
						else {
							/* Drop the old settings from the array */
							unset($vma_host_settings_list[$vma_host_selected_value][$c]);
							} /* End else { */
						} /* End else { */
					} /* End  ($c = 0; $c <= $vma_host_options_counter; $c++) { */
				} /* End if ($vma_host_selected_value != '') { */

			/* Need to do double check for a radio default */
			if ($vmware_object_default_radio_flag == 0) {
				if ($vma_host_options_counter >= 1) {
					if (isset($vma_host_settings_list[$vma_host_selected_value][0][0])) {
						/* Just use the first item in the list */
						$vmware_object_radio_list[$vma_host_selected_value] = $vma_host_settings_list[$vma_host_selected_value][0][0];
						} /* End if (isset($vma_host_settings_list[$vma_host_selected_value][0][0])) { */
					else {
						$vmware_object_radio_list[$vma_host_selected_value] = '';
						} /* End else { */
					} /* End if (count($vma_hosts_list) >= 1) { */
				} /* End if ($vmware_object_default_radio_flag == 0) { */
			
			/* Handle errors */
			if($errors > 0){
				$outargs[COMPONENT_ERROR_MESSAGES] = $errmsg;
				$result = 1;
				return '';
				}

			/* Save settings */
			$settings = array(
				'current_tab' 				=> $current_tab,
				'vma_hosts_list' 			=> $vma_hosts_list,
				'vma_hosts_list_radio' 		=> $vma_hosts_list_radio,
				'vmware_object_radio_list'	=> $vmware_object_radio_list,
				'vma_host_settings_list' 	=> $vma_host_settings_list
				);
			set_option('vmwarevmasettingsmanager_component_options',serialize($settings));

			break; /* End case COMPONENT_CONFIGMODE_SAVESETTINGS: */

		default:
			break;

		} /* End switch($mode) { */

	return $output;
	} /* End function vmwarevmasettingsmanager_component_config_func($mode="",$inargs,&$outargs,&$result) { */


///////////////////////////////////////////////////////////////////////////////////////////
// MISC FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function vmwarevmasettingsmanager_component_checkversion(){

	if(!function_exists('get_product_release'))
		return false;
	//requires greater than 2009R1.2
	if(get_product_release()<114)
		return false;

	return true;
	}


?>
